@@ -993,6 +993,12 @@ const completionSpec: Fig.Spec = {
           description: "Format all files from the current directory",
           isRepeatable: false,
         },
+        {
+          name: ["-c", "--check"],
+          description:
+            "Check if the configs are formatted, no formatting is done",
+          isRepeatable: false,
+        },
         {
           name: ["-s", "--stdin"],
           description:
